//************************************************************************************
//** ParseQueryString.js - ParseQueryString v1.0.2 Class for Jumper
//** This file defines the parse query string class written by Jeff Mott (c) 2004-2005
//** and modified by Steve Perry (c) 2008
//**
//** Jumper Software
//** Version 2.0
//**Copyright: Copyright 2008 Jumper Networks Incorporated
//**Copyright: All Rights Reserved
//**Copyright:
//**Copyright: Licensed under the GNU General Public License (Version 2) published
//**Copyright: by the Free Software Foundation; you may not use this file except in
//**Copyright: compliance with the License. Permission is granted for redistribution
//**Copyright: of this file provided this copyright notice is maintained intact. If
//**Copyright: you alter or modify the contents of this file in any way from its 
//**Copyright: original form please notify Jumper Networks Incorporated.
//**Copyright: 
//**Copyright: Jumper is a trademark of Jumper Networks Incorporated
//**Copyright: which may be registered in certain jurisdictions.
//**EndComments
//**
//**********************************************************************************

Object.prototype.clone = function()
{
    var o = {};
    var property;

    for (property in this) {
        if (typeof this[property] == "object")
            o[property] = this[property].clone();
        else
            o[property] = this[property];
    }

    return o;
}

Array.prototype.clone = function()
{
    var a = [];
    var i;

    for (i = 0; i < this.length; i++) {
        if (typeof this[i] == "object")
            a[i] = this[i].clone();
        else
            a[i] = this[i];
    }

    return a;
}

String.prototype.decodeURL = function() {
    /* unescape has been deprecated in JavaScript 1.5
       this line may need to be changed in a future version */
    return unescape(this.replace(/\+/g, " "));
}

function ParseQueryString()
{
    var parameters = {};
    var parameterNames = [];
	
	this.location = location;

    /* defined for convience and readability */
    function defined(expr)
    {
        return expr != undefined;
    }

    function init()
    {
        var i;
        var pair, pairs;
        var name, value;

        if (this.location.search.length < 2)
            return;

        pairs = this.location.search.substr(1).split(/[&;]/);

        for (i = 0; i < pairs.length; i++)
        {
            pair = pairs[i].split(/=/);

            name = pair[0].decodeURL();
            if (defined(pair[1]))
                value = pair[1].decodeURL();
            else
                value = undefined;

            if (!defined(parameters[name])) {
                parameterNames.push(name);
                if (defined(value))
                    parameters[name] = [value];
                else
                    parameters[name] = [];
            }
            else if (defined(value))
                parameters[name].push(value);
        }
    }
    init();
    
    var scalarParamIndex = 0;
    
    this.param = function(name)
    {
        if (arguments.length) {
            if (defined(parameters[name]))
                return parameters[name][0];
            else
                return undefined;
        }
        else {
            if (scalarParamIndex < parameterNames.length)
                return parameterNames[scalarParamIndex++];
            else {
                scalarParamIndex = 0;
                return undefined;
            }
        }
    }
    
    this.params = function(name)
    {
        if (arguments.length) {
            if (defined(parameters[name]))
                return parameters[name].clone();
            else
                return null;
        }
        else
            return parameterNames.clone();
    }
}
