<?php
//************************************************************************************
//** BoxMsg.php - Box Message Class
//** This file contains the box message parser function to display messages written 
//** by Evgen Leontiev (c) 2005 and modified by Steve Perry (c) 2008
//**
//** Jumper Software
//** Version 2.0
//**Copyright: Copyright 2008 Jumper Networks Incorporated
//**Copyright: All Rights Reserved
//**Copyright:
//**Copyright: Licensed under the GNU General Public License (Version 2) published
//**Copyright: by the Free Software Foundation; you may not use this file except in
//**Copyright: compliance with the License. Permission is granted for redistribution
//**Copyright: of this file provided this copyright notice is maintained intact. If
//**Copyright: you alter or modify the contents of this file in any way from its 
//**Copyright: original form please notify Jumper Networks Incorporated.
//**Copyright: 
//**Copyright: Jumper is a trademark of Jumper Networks Incorporated
//**Copyright: which may be registered in certain jurisdictions.
//**EndComments
//**
//************************************************************************************

/**
 * EXAMPLE:
 * echo HintMsg::quickGet('Test');
 * 
 * $hint = new SuccessMsg();
 * $hint->setMsg('title','SUCCESS {url}');
 * $hint->setMsg('body','If your browser does not support automatic redirection 
 * 			          click this link <a h ref="{url}">{url}</a>');
 * $hint->assignVars('url', '555555');
 * echo $hint->get();
 */

require_once 'jumper_lib/Util/Replacer.php';
require_once 'jumper_lib/Util/GetMsg.php';


class BoxMsg
{	 

	var $error_pref = 'BoxMsg';
	var $vars = array();
	var $img_dir = '';
	var $img;	
	
	var $msg   = array('title'    =>'',
					   'body'     =>'',
					   'header'   =>''); 	
	
	var $color = array('title'    =>'#ffffff',
	                   'body'     =>'#000000'); 
	
	var $bgcolor = array('border' =>'#8592A2', 
					     'body'   =>'#FFFFE1', 
					     'title'  =>'#ffffff');
	

	function BoxMsg () {
		$this->replacer =& new Replacer();
	}	
	
	
	function factory($class, $msgs = array(), $vars = array()) {
		
		$class = ucfirst($class) . 'Msg';
		$m = new $class;
		$m->assignVars($vars);
		
		if($msgs) {
			if(!is_array($msgs)) {
				$args = func_get_args();
				unset($args[0]);
				$msgs = $m->getMsgsArrayFromArgs($args);
			} 
				
			$m->setMsgs($msgs);
			$m = &$m->get();
		}
		
		return $m;
	}
	
	
	function setMsg($msg_key, $msg) {
		$this->msg[$msg_key] = $msg;
	}	
	
	
/*
	function setMsgs1($msgs) {
		foreach($msgs as $k => $v) {
			$this->setMsg($k, $v);
		}
	}
*/
	
	
	function setMsgs($msgs) {
		
		if(!is_array($msgs)) { 	
			$msgs = $this->getMsgsArrayFromArgs(func_get_args());
		} 
		
		foreach($msgs as $k => $v) {
			$this->setMsg($k, $v);
		}		
	}
	
	
	function getMsgsArrayFromArgs($arr) {
		$msg_keys = array_keys($this->msg);
		foreach($arr as $k => $v) {
			$ar[current($msg_keys)] = $v;
			next($msg_keys);
		}

		return $ar;
	}
	
	
	
	function setMsgsIni($file, $msg_file_key) {
		return $this->setMsgs(GetMsg::parseIni($file, $msg_file_key));
	}
	
	
	function get() {
		foreach($this->msg as $k => $v) {
			if(!$v) { continue; }
			$this->msg[$k] = $this->replacer->parse($v);
		}
		
		return $this->getHtml();
	}	
	
	// DEPRECATED
	// echo SctreenMsg::quickGet(array of msg or str if only body);
	function quickGet($msgs = array()) { 
		$class = __CLASS__;
		$m = new $class;
		$m->setMsgs($msgs);
		return $m->getHtml();
	}
	
	
	function assignVars($var, $value = false) {
		$this->replacer->assignVars($var, $value);
	}
	
	
	function & getHtml() {
		$html = '<table width="100%" cellspacing="0" cellpadding="1" bgcolor="'.$this->bgcolor['border'].'">' . "\n";
		$html .= ($this->msg['title']) ?  '<tr><td style="padding: 4px 8px; font-weight: bold; color: '.$this->color['title'].';">'.$this->msg['title'].'</td></tr>' : '';		
		$html .= '<tr><td><table width="100%" cellspacing=0 cellpadding=8 bgcolor="'.$this->bgcolor['body'].'"><tr><td style="color:'.$this->color['body'].';">';
		$html .= ($this->img) ? '<img src="'.$this->img_dir . $this->img.'" alt="" style="margin: 0px 20px 10px 0px; float: left;" />' : '';
		$html .= ($this->msg['header']) ?  '<b>'.$this->msg['header'].'</b><br />' : '';
		$html .= $this->msg['body'];
	 	$html .= '</td></tr></table>' . "\n";
		$html .= '</td></tr></table><br />' . "\n";
		
		return $html;
	}
	
	
	/*
	function getHtml() {
		$tpl = new tplTemplatez($this->tmpl_dir . $this->tmpl);
		if($this->header_msg) { 
			$this->assign('header_msg', $this->header_msg);
			$this->assign('br', '<br>');
		}
		$tpl->tplAssign($this->vars);
		$tpl->tplParse(array('msg' => $this->msg));
		return $tpl->tplPrint(1);
	}
	*/
}


class HintMsg extends BoxMsg
{

	var $img = 'images/icons/hint.gif';
	
	var $msg   = array('title'   =>'',
					   'body'     =>'',
					   'header'   =>'');
	
	var $bgcolor = array('border' =>'#8592A2', 
					     'body'   =>'#FFFFE1', 
					     'title'  =>'#ffffff');
						 

	// DEPRECATED		   
	function quickGet($msgs = array()) { 
		$class = __CLASS__;
		$m = new $class;
		$m->setMsgs($msgs);
		return $m->getHtml();
	}	
}



class ErrorMsg extends BoxMsg
{
	
	var $img;
	
	var $msg   = array('title'   =>'ERROR',
					   'body'     =>'',
					   'header'   =>'');
	
	var $bgcolor = array('border' =>'#cc0033', 
					     'body'   =>'#FFFFE1', 
					     'title'  =>'#ffffff');
						 

	// DEPRECATED
	function quickGet($msgs = array()) { 
		$class = __CLASS__;
		$m = new $class;
		$m->setMsgs($msgs);
		return $m->getHtml();
	}
}



class SuccessMsg extends BoxMsg
{
	
	var $img;
	
	var $msg   = array('title'   =>'SUCCESS',
					   'body'     =>'',
					   'header'   =>'');

	var $bgcolor = array('border' =>'#339900', 
					     'body'   =>'#FFFFE1', 
					     'title'  =>'#ffffff');
						 

	// DEPRECATED
	function quickGet($msgs = array()) { 
		$class = __CLASS__;
		$m = new $class;
		$m->setMsgs($msgs);
		return $m->getHtml();
	}
}





/*
$msg = BoxMsg::factory('hint');
$msg->setMsgs('title', 21321);
echo $msg->get();

$msg = BoxMsg::factory('error');
$msg->setMsgs('title', 21321);
echo $msg->get();

$msg = BoxMsg::factory('success');
$msg->setMsgs('title', 21321);
echo $msg->get();
// or

$msg = new BoxMsg();
$msg->setMsgs('title', 21321);
echo $msg->get();
*/


//echo SuccessMsg::quickGet('title', 21321);


/*
$hint = new SuccessMsg();
$hint->setMsg('title','SUCCESS {url}');
$hint->setMsg('body','If your browser does not support automatic redirection 
			          click this link <a href="{url}">{url}</a>');
$hint->assignVars('url', '555555');
echo $hint->get();
*/

//echo BoxMsg::quickGet('Test');
?>