<?php
//************************************************************************************
//** Backup.php - Backup Class
//** This file contains the function to backup the mySQL database written by Evgen 
//** Leontev (c) 2007 and modified by Steve Perry (c) 2008
//**
//** Jumper Software
//** Version 2.0
//**Copyright: Copyright 2008 Jumper Networks Incorporated
//**Copyright: All Rights Reserved
//**Copyright:
//**Copyright: Licensed under the GNU General Public License (Version 2) published
//**Copyright: by the Free Software Foundation; you may not use this file except in
//**Copyright: compliance with the License. Permission is granted for redistribution
//**Copyright: of this file provided this copyright notice is maintained intact. If
//**Copyright: you alter or modify the contents of this file in any way from its 
//**Copyright: original form please notify Jumper Networks Incorporated.
//**Copyright: 
//**Copyright: Jumper is a trademark of Jumper Networks Incorporated
//**Copyright: which may be registered in certain jurisdictions.
//**EndComments
//**
//************************************************************************************

class Backup
{
	
	var $db_host;
	var $db_base;
	var $db_user;
	var $db_pass;
	var $db_path;	

	var $backup_dir;
	var $filename = 'dump.sql';
	var $win;
	
	
	function Backup() {
		$this->win = $this->isWin();
	}
	
	function isWin() {
		return (substr(PHP_OS, 0, 3) == "WIN");
	}
	
	function setDB($data) {
		$this->db_host = $data['db_host'];
		$this->db_base = $data['db_base'];
		$this->db_user = $data['db_user'];
		$this->db_pass = $data['db_pass'];	
	}
	
	function &factory($engine) {
		$class = 'Backup_' . $engine;
		return new $class;
	}
	
	function _getDBPath() {
		$db_path = $this->db_path;
		if($db_path) {
			$db_path = str_replace('\\', '/', $this->db_path) . '/';
			$db_path = str_replace('//', '/', $db_path);
		}
		
		return $db_path;
	}
}


class Backup_mysql extends Backup
{

	function getDumpCmd() {
		
		$date = date('Y_m_d_h_i_');
		$filename = $date . $this->backup_dir . $this->filename;
		$db_path = $this->_getDBPath();
		
		if($this->win) {
			$cmd_str = '%smysqldump --opt -h %s -u %s -p%s %s > %s';
			$cmd = sprintf($cmd_str, $db_path, $this->db_host, $this->db_user, 
			                         $this->db_pass, $this->db_base, $filename);		
		} else {
			$cmd_str = '%smysqldump --opt -h %s -u %s -p%s %s | gzip > %s.gz';
			$cmd = sprintf($cmd_str, $db_path, $this->db_host, $this->db_user, 
			                         $this->db_pass, $this->db_base, $filename);
		}
		
		return $cmd;
	}
	
	function getRestoreCmd($filename) {
		
		$db_path = $this->_getDBPath();
		
		if(!$this->win) {
			$cmd_str = '%smysql -h %s -u %s -p%s %s < %s';
			$cmd = sprintf($cmd_str, $db_path, $this->db_host, $this->db_user, 
			                         $this->db_pass, $this->db_base, $filename);
		} else {
			$cmd_str = '%smysql gunzip < %s | -h %s -u %s -p%s %s';
			$cmd = sprintf($cmd_str, $db_path, $filename, $this->db_host, $this->db_user, 
			                         $this->db_pass, $this->db_base);
		}
		
		return $cmd;
	}	
	
	function dump() {
		$str = '';
		//system
	}

	function restore() {
	
	}
	

}

/*
$conf['db_host']    = "localhost";
$conf['db_base']    = "dbbase";
$conf['db_user']    = "user";
$conf['db_pass']    = "pass";
$conf['db_path']  	= "";

$backup = Backup::factory('mysql');
$backup->setDB($conf);
$backup->setDB($conf);
//echo $backup->getDumpCmd();
echo $backup->getRestoreCmd('test');
*/


/*
C:\> C:/mysql/bin/mysqldump --opt -u root jmp_25 > sql.dump

C:\> C:/mysql/bin/mysql sql.dump > -u root jmp_25_1

C:\> C:/mysql/bin/mysql -u root jmp_25_1 < C:/sql.dump


C:/mysql/bin/mysqldump --opt -u root jmp_25 | gzip > sql.dump 

mysqldump -h host -u user -ppassword $dbname | gzip > $backupFile

// restore unix
gunzip < custback.sql.gz | mysql -u sadmin -p pass21 Customers
*/
?>