<?php
//************************************************************************************
//** MultiInsert.php - Multiple Insert Class
//** This file contains the SQL function to generate multiple inserts and replace
//** written by Evgen Leontev (c) 2004 and modified by Steve Perry (c) 2008
//**
//** Jumper Software
//** Version 2.0
//**Copyright: Copyright 2008 Jumper Networks Incorporated
//**Copyright: All Rights Reserved
//**Copyright:
//**Copyright: Licensed under the GNU General Public License (Version 2) published
//**Copyright: by the Free Software Foundation; you may not use this file except in
//**Copyright: compliance with the License. Permission is granted for redistribution
//**Copyright: of this file provided this copyright notice is maintained intact. If
//**Copyright: you alter or modify the contents of this file in any way from its 
//**Copyright: original form please notify Jumper Networks Incorporated.
//**Copyright: 
//**Copyright: Jumper is a trademark of Jumper Networks Incorporated
//**Copyright: which may be registered in certain jurisdictions.
//**EndComments
//**
//************************************************************************************

class MultiInsert {
	
	var $fields;
	var $values;
	var $set_quotes = true;							// set quotes for int
	var $special_values = array("NULL", "NOW()");
	var $replace_bracket = array('#___', '___#');
	
	
	function MultiInsert() {}
	
	
	function setFields($values, $other_values = array()) {
	
		$arr = $this->_getArrays($values, $other_values);
		$arr = $this->_appendToArray($arr[0], $arr[1]);
		$this->fields = $this->_arrayToStringFields($arr);
	}
	
	
	function setValues($values, $other_values = array()) {
		
		$arr = $this->_getArrays($values, $other_values);
		$arr = $this->_appendToArray($arr[0], $arr[1]);
		$arr = $this->_setQuotes($arr);
		$this->values = $this->_arrayToString($arr);	
	}
	
	
	function getSql($table, $sql_command = 'INSERT') {
		return "{$sql_command} INTO {$table} ({$this->fields}) VALUES {$this->values}";
	}
	

	function get($sql, $values, $other_values = array()) {
		$a = new MultiInsert();
		$a->setValues($values, $other_values);
		return str_replace('?', $a->values, $sql);
	}
	
	
	function _getArrays($val) {
		$val = func_get_args();
		foreach($val as $k => $v) {
			if($v === false) { continue; }
			$val[$k] = (!is_array($v)) ? array($v) : $v;
 		}
		
		return $val;
	}
	
	
	function _appendToArray(&$arr, &$arr1) {
		
		foreach($arr1 as $k1 => $v1) {
			foreach($arr as $k => $v) {
				
				if(is_array($v)) {
					array_push($arr[$k], $v1); 
				} else {
					array_push($arr, $v1); 
					break;
				}
			}
		}	
		
		return $arr;
	}

	
	function _arrayToStringFields(&$arr, $glue=',') {
		foreach($arr as $k => $v) {
			if(is_array($v)) { 
				$arr[$k] = $this->_arrayToString($v, $glue);
			} 
		}
		
		return join($glue, $arr);
	}	

	
	function _arrayToString(&$arr, $glue=',') {
		foreach($arr as $k => $v) {
			if(is_array($v)) { 
				$arr[$k] = $this->_arrayToString($v, $glue);
			} 
		}
		
		$a = join($glue, $arr);
		$a = (strpos(str_replace('()', '', $a), ')') === false) ? '('.$a.')' : $a;
		return str_replace($this->replace_bracket, array('(', ')'), $a);
	}
	
	
	function _setQuotes(&$arr) {
		foreach($arr as $k => $v) {
			if(is_array($v)) {
				$arr[$k] = $this->_setQuotes($v);
			} else {
				if($v === NULL) { 
					$arr[$k] = "NULL";
				} elseif(in_array($v, $this->special_values)) {
					$arr[$k] = $v;
				} else {
					$v = str_replace(array('(', ')'), $this->replace_bracket, $v);
					$arr[$k] = (is_numeric($v) && !$this->set_quotes) ? $v : "'" . $v . "'";
				}
			}
		}
		return $arr;
	}
}




/*
//EXAMPLE:
$_GET['data'][1] = array(55, 'sss(s)');
$_GET['data'][2] = array(56, 'ddd(d)');

$ins = new MultiInsert;
$ins->setFields(array('name', 'family'), 'id');
$ins->setValues($_GET['data'], 'NOW()');
$sql = $ins->getSql('my_table');

//QUICK WAY:
//$sql = MultiInsert::get("REPLACE table (id,date) VALUES ?", $_GET['data'], array('NOW()'));
echo "<pre>"; print_r($sql); echo "</pre>";
*/

?>