<?php
//************************************************************************************
//** SearchParams.php - Search Parameter Class
//** This file contains search parameters function to generate a "search string" form 
//** for submission written by Evgen Leontev (c) 2003 and modified by Steve Perry
//** (c) 2008
//**
//** Jumper Software
//** Version 2.0
//**Copyright: Copyright 2008 Jumper Networks Incorporated
//**Copyright: All Rights Reserved
//**Copyright:
//**Copyright: Licensed under the GNU General Public License (Version 2) published
//**Copyright: by the Free Software Foundation; you may not use this file except in
//**Copyright: compliance with the License. Permission is granted for redistribution
//**Copyright: of this file provided this copyright notice is maintained intact. If
//**Copyright: you alter or modify the contents of this file in any way from its 
//**Copyright: original form please notify Jumper Networks Incorporated.
//**Copyright: 
//**Copyright: Jumper is a trademark of Jumper Networks Incorporated
//**Copyright: which may be registered in certain jurisdictions.
//**EndComments
//**
//************************************************************************************

// some common functions
class ELCommon 
{
	var $form_action;
	var $form_submit_field;  // to know about certain form submission
	
	
	function setFormAction($form_action) {
		$this->form_action =& $form_action;
	}
	
	function setFormSubmitField($form_field) {
		$this->form_submit_field =& $form_field;
	}
	
	//function setClassVar($var, $value) {
	//	$this->$var = $value;
	//}
	
}

class SearchParams extends ELCommon
{	
	
	var $filter = array();
	var $sess_name = false;
	var $default_sql = '1=1';
	var $default_var = 'all';
	var $sql_sign = '=';
	var $sql_operator = 'AND';
	var $sql_group = false;
	var $sql = false;
	
	// for current field
	var $def_var = false;
	var $def_sql = false;
	var $dateBetweenDefaults = false;
	var $full_text_search = false;
	
	var $use_time = false; // default time for date beetwen will be used
	
	function SearchParams() {
		return true;
	}
	
	// set session name if need to remember submited data 
	function setSessionName($session_name) {
		$this->sess_name = $session_name;
	}
	
	// =, LIKE, ...
	function setSqlSign($sign) {
		$this->sql_sign = $sign;
	}
	
	// AND, OR, ...
	function setSqlOperator($operator) {
		$this->sql_operator = $operator;
	}
	
	// replace * to %, for use with LIKE in sql query
	// serach_all means we add a % to end of str
	function setLikeSql($str, $search_all = false) {
		$str = str_replace('*', '%', $str);
		$this->setSqlSign('LIKE');
		return ($search_all && $str) ? $str . '%' : $str;
	}
	
	
	function parseSeachString($str, $min_letters = 2) {
		
		//     .
		$str = substr($str, 0, 64);
		
		//     "" .
		$str = preg_replace("/[^\w\x7F-\xFF\s]/", " ", $str);
		
		
		if($min_letters) {
		
			// ,      
			//    -   ,    . 
			//,     ,     
			//(  ,   "{1,2}"  "{1, - }").
			
			$preg = sprintf("/\s(\S{1,%d})\s/", $min_letters);
			$str = trim(preg_replace($preg, " ", ereg_replace(" +", "  "," $str ")));
			
			//     -     
			//(        ).
			$str = ereg_replace(" +", " ", $str);
		}
		
		return $str;
	}
	
	
	
	// make full text search
	function setFullTextSearch() {
		$this->full_text_search = true;
	}
	
	
	//function setMoreTables($table, $where_sql) {
	//	$this->more_tables[] = 
	//}
	
	// set sql if could not do in normal way
	function setCustomSql($value, $form_field, $sql, $operator = false) {
		
		if($this->form_submit_field) {
			if($this->sess_name != false) {
				$_SESSION[$this->sess_name][$form_field . '_var'] = $value;
				$_SESSION[$this->sess_name][$form_field . '_sql'] = $sql;
			}
		} else {
		
			// if has such session
			if(isset($_SESSION[$this->sess_name][$form_field . '_var'])) {
				$sql = $_SESSION[$this->sess_name][$form_field . '_sql'];
				$value = $_SESSION[$this->sess_name][$form_field . '_var'];
			}
		}
		
		$this->filter[$form_field]['var'] = $value;
		$this->filter[$form_field]['sql'] = $sql;
		$this->filter[$form_field]['operator'] = ($operator) ? $operator : $this->sql_operator;
		$this->filter[$form_field]['group'] = '';
	}
	
	
	/**
	* setDefaults -- set defaults values if no form submition
	*
	* @param    string    $def_var       default value
	* @param    string    $def_sql       (optional) default sql string to use query
	*
	* @return   void
	* @access   public    
	*/
	function setDefaults($def_var, $def_sql = false) {
		$this->def_var = $def_var;
		$this->def_sql = $def_sql;
	}
	
	
	
   /**
	* setParams -- generate array wit paams per one item to use in sql query
	*
	* @param    string    $value         value of submited form field
	* @param    string    $form_field    field name of submited form field
	* @param    mixed     $sql_field     sql field name
	* @param    string    $group         (optional) 'start' or 'stop' 
	* @param    string    $operator      (optional) sql operator to use in sql string, AND by default
	*
	* @example  $obj->setParams($_GET['blah'], 'blah', 'p.blah', '', 'OR');
	*
	* @return   void
	* @access   public    
	*/
	function setParams($value, $form_field, $sql_field, $group = false, $operator = false) {
		
		// if is array $sql_field can be in full text search
		if(is_array($sql_field)) { $sql_field = implode(', ', $sql_field); }
		
		// for using in IN
		if(is_array($value)) { $value = '(' . implode(',', $value) . ')'; }
		
		// if form submited and value not default
		if($this->form_submit_field) {
			$ret = mysql_escape_string(trim($value));
			$sql = ($this->full_text_search) ? "MATCH ($sql_field) AGAINST ('{$ret}')" : "{$sql_field} {$this->sql_sign} '{$ret}'";
			$var = trim($value);
			
			// set session if needed
			if($this->sess_name != false) {
				$_SESSION[$this->sess_name][$form_field . '_var'] = $var;
				$_SESSION[$this->sess_name][$form_field . '_sql'] = $sql;
			}
			
		} else {
			
			// if has such session
			if(isset($_SESSION[$this->sess_name][$form_field . '_var'])) {
				$sql = $_SESSION[$this->sess_name][$form_field . '_sql'];
				$var = $_SESSION[$this->sess_name][$form_field . '_var'];
			
			// by default
			} elseif($this->def_var !== false) {	
				if($this->full_text_search) {
					$sql = ($this->def_sql) ? $this->def_sql : "MATCH ($sql_field) AGAINST  ('{$this->def_var}')";
				} else {
					$sql = ($this->def_sql) ? $this->def_sql : "{$sql_field} {$this->sql_sign} '{$this->def_var}'";
				}
				$var = $this->def_var;
			
			// all others
			} else {
				$sql = $this->default_sql;
				$var = $this->default_var;
			}
		}
		
		// to strip IN'(1,2)' to get IN (1,2)
		$sql = str_replace(array("'(", ")'"), array("(", ")"), $sql);
		
		$this->filter[$form_field]['var'] = $var;
		$this->filter[$form_field]['sql'] = $sql;
		$this->filter[$form_field]['operator'] = ($operator) ? $operator : $this->sql_operator;
		$this->filter[$form_field]['group'] = $group;
		
		// unset defaults for current var & sql
		$this->def_var = false;
		$this->def_sql = false;
	}
	
	
   /**
	* getVars -- for use in form field if needed
	*
	* @return   array
	* @access   public    
	*/
	function getVars() {
		$data = array();
		foreach($this->filter AS $k => $v) {
			
			if(is_array($v['var'])) {
				foreach($v['var'] as $k1 => $v1) {
					if($v1 && $v1 !== $this->default_var) {
						$data[$k1] = str_replace('%', '*', $v1); // convert back
					}
				}
			} else {
				if($v['var'] && $v['var'] !== $this->default_var) {
					$data[$k] = str_replace('%', '*', $v['var']); // convert back
				}
			} 
		}
		return $data;
	}
	

   /**
	* getSQL -- generate sql string, for use in sql query
	*
	* @return   string
	* @access   public    
	*/
	function getSQL() {
		$sql_str = false;
		foreach($this->filter AS $k => $v) {
			//if($v['sql'] != $this->default_sql) {
			if($v['var'] !== '' && $v['var'] !== $this->default_var) {
				if($v['group']) {
					$sql_str .= ($v['group'] == 'start') ? $v['operator'].' ('.$v['sql'] : $v['operator'].' '.$v['sql'].')';
					$sql_str .=  "\n";
				} else {
					$sql_str .= $v['operator'] . ' ' . $v['sql'] . "\n";
				}
			}
		}
		$sql_str = $this->default_sql . ' ' . $sql_str;
		return $sql_str;
	}
	
	
	// $date_from_val, $date_till_val - in UNIXTIMESTAMP
	function setDateBetweenDefaults($date_from_val, $date_till_val) {
		$this->def_date_from = $date_from_val;
		$this->def_date_till = $date_till_val;		
		$this->dateBetweenDefaults = true;
	}
	
	
	// date BETWEEN '20031210' AND '20031215'";
	function setDateBetweenParams($date_from_val, $date_till_val, $form_field, $sql_field, $group = false, $operator = false) {
		
		//if(!empty($date_from_val)) {
		if($this->form_submit_field) {	
		
			if($date_from_val) {
				$date_from_sql = $this->setDateValue($date_from_val, 'from');
				$date_till_sql = $this->setDateValue($date_till_val, 'to');
				$sql = "{$sql_field} BETWEEN '{$date_from_sql}' AND '{$date_till_sql}'";
				$var_from = $date_from_val;
				$var_till = $date_till_val;
			} else {
				$var_from = $this->default_var;
				$var_till = $this->default_var;
				$sql = $this->default_sql;
			}
			
			
			// set session if needed
			if($this->sess_name != false) {
				$_SESSION[$this->sess_name]['date_beetwen_from'] = $var_from;
				$_SESSION[$this->sess_name]['date_beetwen_till'] = $var_till;
				$_SESSION[$this->sess_name]['date_beetwen_sql']  = $sql;
			}
			
		} else {
			
			// if has such session
			if(isset($_SESSION[$this->sess_name]['date_beetwen_from'])) {
				$var_from = $_SESSION[$this->sess_name]['date_beetwen_from'];
				$var_till = $_SESSION[$this->sess_name]['date_beetwen_till'];
				$sql = $_SESSION[$this->sess_name]['date_beetwen_sql'];
			
			// by default
			} elseif($this->dateBetweenDefaults) {
				$var_from = $this->def_date_from;
				$var_till = $this->def_date_till;
				
				$date_from_sql = $this->setDateValue($var_from, 'from');
				$date_till_sql = $this->setDateValue($var_till, 'to');
				$sql = "{$sql_field} BETWEEN '{$date_from_sql}' AND '{$date_till_sql}'";
			
			// all others
			} else {
				$var_from = $this->default_var;
				$var_till = $this->default_var;
				$sql = $this->default_sql;
			}
		}
		
		$this->filter[$form_field]['var']['from'] = $var_from;
		$this->filter[$form_field]['var']['till'] = $var_till;
		$this->filter[$form_field]['sql'] = $sql;
		$this->filter[$form_field]['operator'] = ($operator) ? $operator : $this->sql_operator;
		$this->filter[$form_field]['group'] = $group;
		
		// unset defaults for current var & sql
		//$this->def_var = false;
		//$this->def_sql = false;
	}
	
	
	function setDateValue($timestamp, $what) {
		
		$time = ($what == 'from') ? '000000' : '235959';
		return ($this->use_time) ? date('YmdHis', $timestamp) : date('Ymd', $timestamp) . $time;		
	}

} // <-- class end
?>