<?php
//**********************************************************************************
//** JumperPageRenderer.php - Client Page Renderer
//** This file contains the client page renderer written by Evgen Leontev (c) 2005
//** modified by Steve Perry (c) 2008
//**
//** Jumper Software
//** Version 2.0
//**Copyright: Copyright 2008-2009 Jumper Networks Incorporated
//**Copyright: All Rights Reserved
//**Copyright:
//**Copyright: Licensed under the GNU General Public License (Version 2) published
//**Copyright: by the Free Software Foundation; you may not use this file except in
//**Copyright: compliance with the License. Permission is granted for redistribution
//**Copyright: of this file provided this copyright notice is maintained intact. If
//**Copyright: you alter or modify the contents of this file in any way from its 
//**Copyright: original form please notify Jumper Networks Incorporated.
//**Copyright: 
//**Copyright: Jumper is a trademark of Jumper Networks Incorporated
//**Copyright: which may be registered in certain jurisdictions.
//**EndComments
//**
//**********************************************************************************

class JumperPageRenderer
{

	var $site_path;
	var $title_delim = ' / ';

	
    function JumperPageRenderer(&$view, &$manager) {
		$this->setCommonVars($view, $manager);
		$this->site_path = APP_CLIENT_PATH;
    }

	
	function setCommonVars(&$view, &$manager) {
        $this->view = &$view;
		$this->manager = &$manager;
		$this->vars['base_href'] = $this->view->conf['client_home_path'] . 'client/';	
	}
	
	
	 function render() {
		 
		if($this->isOnePageTemplate()) {
			
			$tpl = &new tplTemplatez($this->getTemplate());
			
			$data['content'] = &$this->view->execute($this->manager);
			$data['content'] .= $this->getCopyright();
			$data['meta_title'] = $this->getMetaTitle();
			$data['meta_charset'] = $this->getMetaCharset();
			$data['meta_robots'] = $this->getMetaRobots($this->view->view_id);
			$data['meta_keywords'] = $this->view->meta_keywords;
			$data['meta_location'] = $this->view->meta_location;
			$data['meta_link'] = $this->view->meta_link;
			$data['meta_datatype'] = $this->view->meta_datatype;
			$data['rss_head_links'] = $this->view->getRssHeadLinks($this->manager);
			//echo "<pre>"; print_r($this->view); echo "</pre>";
			
			$tpl->tplAssign($this->view->css);
			$tpl->tplParse(array_merge($this->vars, $data));
			return $tpl->tplPrint(1);			
		
		} else {

			$page = $this->getHeaderFooter();
			
			include $page[0];
			
			$str = '<link rel="stylesheet" type="text/css" href="%s" />';
			foreach($this->view->css as $v) { 
				$css[] = sprintf($str, $v);
			}
			echo implode("\n", $css) . "\n";
			
			echo $this->view->execute($this->manager);
			echo $this->getCopyright();
			include $page[1];
		}
	}
	
	
	function isOnePageTemplate() {
		return (strpos($this->manager->setting['page_to_load'], ';') === false);
	}
	
	
	function getHeaderFooter() {
		$ar = explode(';', $this->manager->setting['page_to_load']);
		$ar[0] = trim($ar[0]);
		$ar[1] = trim($ar[1]);
		
		return $ar;

		$jumper_str = '';
		if($this->manager->getSetting('logo_generate') != 'none') {
			$str = '
			<div style="float: left;">
				<a href="%s"><img src="%s/images/logo/jumper_logo.jpg" alt="Jumper" width="195" height="85" border="0" /></a>
			</div>';
			$logo_str = sprintf($str, $this->view->_getLink['product_www'], $this->site_path . 'client');
		}
}
	
	
	function getTemplate() {
		if(strtolower($this->manager->setting['page_to_load']) == 'default') {
			$page = $this->view->template_dir . $this->view->page_template; 
		} else {
			$page = $this->manager->setting['page_to_load'];
		}
		
		return $page;
	}
	
	
	// set title of page
	function getMetaTitle() {
		
		$data = array();
		if($this->manager->getSetting('site_title')) {
			$data[] = $this->manager->getSetting('site_title');
			
			if($this->view->view_id == 'files') {
				$data[] = $this->view->msg['file_title_msg'];
			}
		}
		
		if($this->view->meta_title) {
			$data[] = $this->view->meta_title;
		}
		
		return implode($this->title_delim, $data);
	}
	
	
	function getMetaRobots($view) {
		
		// array with view keys for what we use 
		//<meta name="robots" content="all">
		$all_arr = array('index', 'entry', 'glossary', 'rssfeed');
		$meta_robots = 'NONE';
		
		if(in_array($view, $all_arr)) {
			$meta_robots = 'ALL';
		} 
		
		return $meta_robots;
	}
	
	
	function getMetaCharset() {
		return $this->view->conf['lang']['meta_charset'];
	}
	
	
	function getCopyright() {

		$rss_str = '';
		if($this->manager->getSetting('rss_generate') != 'none') {
			$str = '
			<div style="float: right;">
				<a href="%s"><img src="%s/images/icons/rssv2.gif" alt="RSS" width="80" height="15" border="0" /></a>
			</div>';
			$rss_str = sprintf($str, $this->view->_getLink('rssfeed'), $this->site_path . 'client');
		}
	
		$str = '<br /><br />
				<hr size="1" noshade="noshade" />%s
				<div align="left" class="copyright"> %s 
					<a href="%s" title="%s" target="_blank"><b>%s</b></a> <span>(%s)</span>
				</div>
				</div><br />';
		
		return sprintf($str, $rss_str,
							 'Powered by',
		                     $this->view->conf['product_www'],
							 'Jumper 2.0.1.4',
							 'Jumper Networks',
							 'Jumper 2.0.1.4'
							 );
	}
	
	
	function getCache() {
		
		require_once 'jumper_lib/Util/ResultCache.php';
		
		$cache = new ResultCache();
		$cache->refresh = true;
		$cache->cache_dir = APP_CACHE_DIR;
		$cache->setUserFuncVars(array($this, 'render'));
		
		$cache_id = md5('.ht' . $_SERVER['PHP_SELF'] . $_SERVER['QUERY_STRING'] . AuthMember::getRoleId());
		return $cache->getData($cache_id);
	}
	
	
	function display() {
	
		//timestart("cache");
		//echo $this->getCache();
		//timestop("cache");
		
		//timestart("no cache");
		echo $this->render();
		//timestop("no cache");
	}
}
?>