<?php
//**********************************************************************************
//** JumperRSSModel.php - Client RSS Model
//** This file contains the client RSS model written by Evgen Leontev (c) 2005
//** modified by Steve Perry (c) 2008
//**
//** Jumper Software
//** Version 2.0
//**Copyright: Copyright 2008-2009 Jumper Networks Incorporated
//**Copyright: All Rights Reserved
//**Copyright:
//**Copyright: Licensed under the GNU General Public License (Version 2) published
//**Copyright: by the Free Software Foundation; you may not use this file except in
//**Copyright: compliance with the License. Permission is granted for redistribution
//**Copyright: of this file provided this copyright notice is maintained intact. If
//**Copyright: you alter or modify the contents of this file in any way from its 
//**Copyright: original form please notify Jumper Networks Incorporated.
//**Copyright: 
//**Copyright: Jumper is a trademark of Jumper Networks Incorporated
//**Copyright: which may be registered in certain jurisdictions.
//**EndComments
//**
//**********************************************************************************

require_once APP_MODULE_DIR . 'setting/inc/SettingModel.php';
require_once 'jumper_lib/Util/TreeHelper.php';


class JumperRSSModel extends BaseModel
{

	var $tbl_pref_custom = 'jmp_';
	var $tables = array('entry', 'category', 'entry_to_category');
	var $custom_tables = array('file_entry');
	
	
	function getEntriesSql($limit) {
		
		$sql = "
		SELECT 
			e.id AS entry_id,
			e.title,
			e.body AS description,
			cat.name AS category,
			cat.id AS category_id,
			UNIX_TIMESTAMP(e.date_updated) AS pubDate

		FROM 
			{$this->tbl->entry} e, 
			{$this->tbl->category} cat,
			{$this->tbl->entry_to_category} e_to_cat								
		
		WHERE 1
			AND e.id = e_to_cat.entry_id
			AND cat.id = e_to_cat.category_id
			AND e.active = 1
			AND cat.active = 1
			AND e.private = 0
			AND cat.private = 0
			AND {$this->sql_params}
		GROUP BY e.id	
		ORDER BY e.date_updated DESC
		LIMIT {$limit}";
		
		//echo "<pre>"; print_r($sql); echo "</pre>";
		return $sql;
	}
	
	
	function &getEntries($category_id, $cat, $controller, $limit = 15, $desc_signs = 250) {
		
		if($category_id) {
			$tree = &new TreeHelper();
			foreach($cat as $k => $row) {
				$tree->setTreeItem($row['id'], $row['parent_id']);
			}
			
			$child_category_ids = $tree->getChildsById($category_id);
			$child_category_ids[$category_id] = $category_id;
			$child_category_ids = implode(',', $child_category_ids);
			
			$this->setSqlParams("AND e_to_cat.category_id IN($child_category_ids)");
		}

		
		$sql = $this->getEntriesSql($limit);
		$result = &$this->db->Execute($sql) or die(db_error($sql));
		
		$data = array();
		while($row = $result->FetchRow()) {
			$data[$row['entry_id']] = $row;
			$data[$row['entry_id']]['description'] = DocumentParser::getSummary($row['description'], $desc_signs);
			$data[$row['entry_id']]['category'] = $this->getParentCategoriesTitles($cat, $row['category_id']);
			$data[$row['entry_id']]['link'] = $controller->getLink('entry', $row['category_id'], $row['entry_id']);
		}
		
		//echo "<pre>"; print_r($data); echo "</pre>";
		//echo "<pre>"; print_r($sql); echo "</pre>";
		
		return $data;
	}
	
	
	function &getCategories() {
		$sql = "SELECT id as id1, id, parent_id, name FROM {$this->tbl->category}
		WHERE active = 1
		AND private = 0";
		$result =& $this->db->Execute($sql) or die(db_error($sql));
		return $result->GetAssoc();
	}
	
	
	function getParentCategoriesTitles($categories, $category_id) {
		$categories = TreeHelperUtil::getParentsById($categories, $category_id, 'name');
		return implode('/', $categories);
	}
	
	
	function &getCategoryData($category_id) {
		$sql = "SELECT name AS title, description FROM {$this->tbl->category} 
		WHERE id = '{$category_id}'";
		$result =& $this->db->Execute($sql) or die(db_error($sql));
		return $result->FetchRow();
	}
	
	
	function getChannelData($category_id, $categories, $controller) {
		
		$data = array();
		$setting = &$this->getSettings();
		
		$data['title'] = $setting['rss_title'];
		$data['link'] = $controller->jmp_path;
		$data['description'] = $setting['rss_description'];
		
		if($category_id) {
			$str = '%s (%s)';
			$category_data = $this->getCategoryData($category_id);
			
			$data['title'] = sprintf($str, $data['title'], $category_data['title']);
			if($category_data['description']) {
				$data['description'] = sprintf($str, $data['description'], $category_data['description']);
			}
			
			$data['link'] = $controller->getLink('index', $category_id);
		}
		
		return $data;
	}
	
	
	function &getSettings() {
		$s = &new SettingModel();
		$s->module_id = '100';
		$s->module_name = '';
		return $s->getSettings();	
	}
}
?>