<?php
//**********************************************************************************
//** JumperView_entry.php - Client View Entry
//** This file contains the client view entry written by Evgen Leontevm (c) 2005
//** modified by Steve Perry (c) 2008
//**
//** Jumper Software
//** Version 2.0
//**Copyright: Copyright 2008-2009 Jumper Networks Incorporated
//**Copyright: All Rights Reserved
//**Copyright:
//**Copyright: Licensed under the GNU General Public License (Version 2) published
//**Copyright: by the Free Software Foundation; you may not use this file except in
//**Copyright: compliance with the License. Permission is granted for redistribution
//**Copyright: of this file provided this copyright notice is maintained intact. If
//**Copyright: you alter or modify the contents of this file in any way from its 
//**Copyright: original form please notify Jumper Networks Incorporated.
//**Copyright: 
//**Copyright: Jumper is a trademark of Jumper Networks Incorporated
//**Copyright: which may be registered in certain jurisdictions.
//**EndComments
//**
//**********************************************************************************

require_once 'jumper_lib/Util/CryptEmail.php';
require_once APP_MODULE_DIR . 'knowledgebase/comment/inc/JMPCommentView_helper.php';


class JumperView_entry extends JumperView_common
{

	function &execute(&$manager) {
		
		$row = &$manager->getEntryById($this->entry_id, $this->category_id);
		$row = &$this->stripVars($row);
		if(!$row) { $t = ''; return $t; }
		
		
		$this->meta_title = &$row['title'];
		$this->meta_keywords = &$row['meta_keywords'];
		$this->meta_location = &$row['meta_location'];
		$this->meta_link = &$row['meta_link'];
		$this->meta_datatype = &$row['meta_datatype'];
		
		$title = '';
		if($manager->getSetting('show_title_nav') && strlen($row['title']) < 80) {
			$title = $row['title'];
		}
		
		$data = $this->getTop($manager, $title);
		$data .= $this->getEntry($manager, $row);
		$data .= $this->getEntryListAttachment($manager);
		$data .= $this->getCommentList($manager);
		
		if($this->isCommentable($manager, $row['commentable'])) {
			if(!$manager->is_registered && $manager->getSetting('allow_comments') == 2) {
			
			// display form if at least one comment exists
			} elseif($manager->isComments($this->entry_id)) {
				$data .= $this->getCommentForm($manager);		
			}
		}
		
		$related = &$this->stripVars($manager->getEntriesRelated($this->entry_id));
		
		$data .= $this->getEntryListRelated($manager, $related);
		$data .= $this->getEntryListCategory($manager, $related);
		
		return $data;		
	}
	
	
	function getEntry(&$manager, &$row)  {
		
		$glossary_items = &$manager->getGlossaryItems();
		if($glossary_items) {
			$row['body'] = DocumentParser::parseGlossaryItems($row['body'], $glossary_items, $manager);
		}
		
		if(DocumentParser::isLink($row['body'])) {
			$row['body'] = DocumentParser::parseLink($row['body'], array($this, '_getLink'), $manager, $this->entry_id);	
		}
	
		//if(DocumentParser::isCode($row['body'])) { echo 1;
		//	$row['body'] = DocumentParser::parseCode($row['body'], $this->conf['client_home_path']);
		//}
		
		
		$tpl = &new tplTemplatez($this->template_dir . 'profile.html');
		
		$tpl->tplAssign('rating', $this->_getRating($row['rating']));
		$tpl->tplAssign('updated_date', $this->getFormatedDate($row['ts_updated']));
		$tpl->tplAssign('profile_block', $this->getEntryBlock($row, $manager));
		$tpl->tplAssign('base_href', $this->conf['client_home_path']);
		
		$tpl->tplParse(array_merge($row, $this->msg));
		return $tpl->tplPrint(1);
	}
	
	
	function getEntryBlock($data, $manager) { 
		
		$tpl = &new tplTemplatez($this->template_dir . 'profile_block.html');
		
		$tpl->tplAssign('profile_id', $data['id']);
		$tpl->tplAssign('category_id', $data['category_id']);	
		$tpl->tplAssign('print_link', $this->_getLink('print', $data['category_id'], $data['id']));
		
		
		// profile creators,  dates
		if($manager->getSetting('show_creator')) {
			
			$tpl->tplAssign('date_posted_formated', $this->getFormatedDate($data['ts_posted']));
			$tpl->tplAssign('date_updated_formated', $this->getFormatedDate($data['ts_updated']));
			
			require_once 'jumper_lib/Item/PersonHelper.php';
			$user = $manager->getAdminInfo($data['creator_id']);
			$tpl->tplAssign('creator', PersonHelper::getShortName($user));
			
			$user = $manager->getAdminInfo($data['updater_id']);
			$tpl->tplAssign('updater', PersonHelper::getShortName($user));
			
			$tpl->tplSetNeeded('/creator_block');
		}
		
		
		if($manager->getSetting('show_hits')) {
			$tpl->tplSetNeededGlobal('show_hits');
		}
		
		if($manager->getSetting('show_send_link')) {
			$tpl->tplSetNeededGlobal('send_link');
			$tpl->tplAssign('send_link', $this->_getLink('send', $data['category_id'], $data['id']));		
		}		
		
		if($this->isCommentable($manager, $data['commentable'])) {
			$tpl->tplSetNeededGlobal('commentable');
			$tpl->tplAssign('comment_link', $this->_getLink('comment', $data['category_id'], $data['id']));		
		}
		
		
		if($this->isRatingable($manager, $data['ratingable'])) {
			
			$tpl->tplSetNeededGlobal('ratingable');
			
			if($manager->isUserVoted($data['id']) === false) {
				$select = new FormSelect();
				$select->select_tag = false;
				$select->setRange($this->_getRateRange(), array(0=>$this->msg['add_rate_msg']));
				$tpl->tplAssign('rating_select', $select->select());
				$tpl->tplSetNeeded('/vote_form');
			
			} else {
			
				$tpl->tplAssign('rating', $this->_getRating($data['rating']));
				$tpl->tplSetNeeded('/show_rating');
			}
			
			
			$tpl->tplAssign('form_action', $this->_getLink('entry', $data['category_id'], $data['id']));
			$tpl->tplAssign('votes', ($data['votes']) ? $data['votes'] : 0);		
		}		
		
		
		$tpl->tplParse(array_merge($data, $this->msg));
		return $tpl->tplPrint(1);
	}
	
	
	function getEntryListAttachment(&$manager) {
		
		$rows = $manager->getAttachmentList($this->entry_id);
		if(!$rows) { return; }

		$tpl = &new tplTemplatez($this->template_dir . 'profile_list_attachment.html');
			
		foreach($rows as $file_id => $v) {
			
			// need to fix when file private
			//$private = ($v['private'] || $v['category_private']);
			//$v['item_img'] = $this->_getItemImg($manager->is_registered, $private, true);
			
			$ext = substr($v['filename'], strrpos($v['filename'], ".")+1);
			$v['item_img'] = $this->_getItemImg($manager->is_registered, false, 'file', $ext);

			$v['filesize'] = WebUtil::getFileSize($v['filesize']);
			$v['attachment_link'] = $this->_getLink('file', $this->entry_id, $file_id);
			$v['attachment_title'] = ($v['title']) ? $v['title'] : $v['filename'];
			$v['attachment_title'] = $this->stripVars($v['attachment_title']);
			$tpl->tplParse($v, 'row');
		}
		
		$tpl->tplAssign('title_msg', $this->msg['attachment_title_msg']);
		$tpl->tplParse();
		return $tpl->tplPrint(1);
	}	
	
	
	function getEntryListCategory(&$manager, $have_related) {
		
		$limit_num = $manager->getSetting('num_entries_category');
		$rows = &$this->stripVars($manager->getEntriesCategory($this->category_id, $this->entry_id, $limit_num));
		$rows_num = count($rows);
		if(!$rows) { return; }
		
		
		$tpl = &new tplTemplatez($this->template_dir . 'profile_list_category.html');
		
		if($limit_num != 'all' && ($rows_num > $limit_num)) {
		
			shuffle($rows);
			$rows = &array_slice($rows, 0, $limit_num);
		
			$tpl->tplAssign('category_link', $this->_getLink('index', $this->category_id));
			$tpl->tplAssign('category_link_msg', $this->msg['more_entries_msg']);
			$tpl->tplSetNeeded('/category_link');
		}		

		foreach($rows as $k => $v) {
			$v['item_img'] = $this->_getItemImg($manager->is_registered, $v['private']);
			$v['entry_link'] = $this->_getLink('entry', $this->category_id, $v['entry_id']);
			$v['title'] = $this->stripVars($v['title']);
			
			$tpl->tplParse($v, 'row');
		}
		
		$tpl->tplAssign('title_msg', $this->msg['entry_category_title_msg']);
		$tpl->tplParse();
		return $tpl->tplPrint(1);
	}
	
	
	function getEntryListRelated(&$manager, $rows) {
		
		if(!$rows) { return; }
		
		$tpl = &new tplTemplatez($this->template_dir . 'profile_list_related.html');
		
		foreach($rows as $k => $v) {
		
			$private = ($v['private'] || $v['category_private']);
			$v['item_img'] = $this->_getItemImg($manager->is_registered, $private);
			$v['entry_link'] = $this->_getLink('entry', $v['category_id'], $v['entry_id']);
			$v['title'] = $this->stripVars($v['title']);
			
			$tpl->tplParse($v, 'row');
		}
		
		$tpl->tplAssign('title_msg', $this->msg['entry_related_title_msg']);
		$tpl->tplParse();
		return $tpl->tplPrint(1);
	}		
	
	
	function getCommentList(&$manager) {
		
		$tpl = &new tplTemplatez($this->template_dir . 'comment_list.html');
		
		$bp = $this->pageByPage(20, $manager->getCommentListCountSql($this->entry_id));
		$by_page = $bp->shortNavigate();
		$tpl->tplAssign('page_by_page', $by_page);
		
		if($bp->num_pages > 1) {
			$tpl->tplSetNeeded('/by_page_bottom');
		}
		
		$rows = &$this->stripVars($manager->getCommentList($this->entry_id, $bp->limit, $bp->offset));
		if(!$rows) { return; }
		
		
		$parser = &JMPCommentView_helper::getBBCodeObj();
		
		foreach($rows as $k => $row) {
			
			if($row['email']) {
				$tpl->tplSetNeeded('row/if_email');
				$tpl->tplAssign('mailto_link', CryptEmail::getMailto($row['email']));
			} elseif($row['name']) {
				$tpl->tplSetNeeded('row/if_name');
			}
			
			$tpl->tplAssign('comment', $parser->qparse(nl2br($row['comment'])));		
			$tpl->tplAssign('formated_date', $this->getFormatedDate($row['ts']));
			$tpl->tplParse($row, 'row');
		}
		
		$tpl->tplAssign('jmp_path', $this->controller->jmp_path);
		$tpl->tplAssign('var', 'value');
		$tpl->tplAssign('js_script', CryptEmail::getMailtolJs(false));
		$tpl->tplAssign($this->msg);
		$tpl->tplParse();
		return $tpl->tplPrint(1);
	}	
	
	
	function getCommentForm($manager) {
		
		$tpl = &new tplTemplatez($this->template_dir . 'comment_form.html');
		
		$tpl->tplAssign('action_link', $this->_getLink('comment', $this->category_id, $this->entry_id));
		
		if(!$manager->is_registered) {
			$tpl->tplSetNeeded('/not_registered');
		}
		
		if($this->useCaptcha($manager, 'comment')) {
			$tpl->tplSetNeeded('/captcha');
			$tpl->tplAssign('captcha_src', $this->getCaptchaSrc());
		}		
		
		
		$tpl->tplAssign('toggle_form', 1);
		$tpl->tplAssign('display_form', 'none');		
		
		$tpl->tplAssign('jmp_path', $this->controller->jmp_path);
		$tpl->tplAssign($this->msg);
		$tpl->tplAssign($this->getFormData());	
		
		$tpl->tplParse();
		return $tpl->tplPrint(1);
	}
}
?>